#!/usr/bin/env node

const path = require('path')
const program = require('commander')
const compile = require('./lib/compile')
const createFile = require('./lib/createFile')

program
  .command('create [filename]')
  .alias('c')
  .description('Cli to create .vue and .css together in directory')
  .option('-v, --version [type]', 'create vue component with optionApi(version:2) or compositionApi(version:3) or scriptSetup', '3')
  .option('-p, --path [path]', 'create vue component with folder ', 'src/views')
  .option('-c, --css [style]', 'vue style with "css/less/scss" ', 'css')
  .option('-st, --setup', 'create vue component with "setup"', true)
  .option('-t, --ts', 'create vue component with "ts"', false)
  .option('-s, --scoped', 'vue style with scoped', true)
  .action(async function () {
    // 获取命令行数据
    const options = this.opts()
    const filename = this.args[1] || 'index'
    const cssStyle = options.css

    // 文件输出路径: 默认路径: defaultPath, 用户输入路径:dirOutputPath
    const defaultPath = path.resolve(process.cwd(), 'src/views')
    const dirOutputPath = options.path ? path.join(process.cwd(), options.path, filename) : defaultPath

    // 编译要写入的模板数据
    const data = await compile(options, filename, cssStyle)

    // 生成文件
    createFile(dirOutputPath, filename, cssStyle, data)
  })
  .parse()
