const { readFile } = require('node:fs/promises')
const path = require('path')

/**
 * @description 编译模板
 * @param {object} options 命令行输入的配置项
 * @param {string} filename create命令生成文件的名字
 * @param {string} cssStyle 输出css文件的类型
 * @returns {object} data
 */

async function compile(options, filename, cssStyle) {
  let script
  const readFilePath = path.resolve(__dirname, '../tpl/optionsApi.tpl')

  if (options.version === '2') {
    try {
      script = await readFile(readFilePath, 'utf-8')
    } catch (error) {
      throw error
    }
  }

  if (options.version === '3') {
    script = `<script${options.ts ? ' lang="ts"' : ''}${options.setup ? ' setup' : ''}>\n\n</script>`
  }

  const data = {
    className: filename,
    style: cssStyle,
    script,
    style: `<style${options.css === 'css' ? '' : ` lang="${options.css}"`}${options.scoped ? ' scoped' : ''}>\n\n</style>`
  }

  return data
}
module.exports = compile
