const path = require('path')
const fs = require('fs')
const mkdirp = require('mkdirp')
const Handlebars = require('handlebars')
const message = require('./utils')

/**
 * @description  生成最终的vue文件和css文件
 * @param {string} dirOutputPath 输出的文件夹路径
 * @param {string} filename 输出文件的名字
 * @param {string} cssStyle 输出css文件的类型
 * @param {object} data 替代模板的数据
 */

function createFile(dirOutputPath, filename, cssStyle, data) {
  const vueOutputPath = path.join(dirOutputPath, `${filename}.vue`)
  const cssOutputPath = path.join(dirOutputPath, `${filename}.${cssStyle}`)
  const readFilePath = path.resolve(__dirname, '../tpl/example.tpl')

  // 生成文件夹
  mkdirp(dirOutputPath).then(() => {
    // 读取vue模板
    fs.readFile(readFilePath, 'utf-8', (err, source) => {
      if (err) throw err

      const template = Handlebars.compile(source)
      const result = template(data)

      // 写入vue文件
      fs.writeFile(vueOutputPath, result, (err) => {
        if (err) throw err
        message.success(`${filename}.vue create successfully!`)
      })
      // 写入css文件
      fs.writeFile(cssOutputPath, '', (err) => {
        if (err) throw err
        message.success(`${filename}.${cssStyle} create successfully!`)
      })
    })
  })
}

module.exports = createFile
